ScanRejected class final

The frame was turned away; see rejection.

Inheritance

Constructors

ScanRejected(ScanRejection rejection)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
rejection ScanRejection
Why the frame was turned away.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited