SolSignType class abstract final

sol-sign-request signType (CBOR key 7).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

message → const int
Off-chain message: key 7 = 2. The device signs the bytes VERBATIM (no prefix).
transaction → const int
Key 7 is OMITTED on the wire for a transaction (the device's default).