SolanaChain class

The Solana chain module: sol-sign-request out, sol-signature back.

Constructors

SolanaChain([EraConnectConfig? config])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateSignRequest(SolSignRequestProps props) SignRequest<SolSignatureResult>
Build a sol-sign-request (1101). Reply: sol-signature (1102).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseSignature(Object input, [ExpectedReply? expect]) SolSignatureResult
Parse a sol-signature standalone. Prefer SignRequest.scanner().parse().
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited