TronLatestBlock class

A live now-block anchor for a Tron transaction.

Constructors

TronLatestBlock({required String hash, required int number, required int timestamp})
const

Properties

hash String
FULL 64-hex block id of a live now-block (the device slices ref_block_hash from it).
final
hashCode int
The hash code for this object.
no setterinherited
number int
The block height.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
The block timestamp in Unix milliseconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited