DecodedBchInput class

One decoded input of a legacy-serialized transaction.

Constructors

DecodedBchInput({required Uint8List txidLE, required int index, required Uint8List scriptSig, required int sequence})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptSig Uint8List
final
sequence int
final
txidLE Uint8List
The outpoint txid in wire (little-endian) order.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited