DecodedBchOutput class

One decoded output of a legacy-serialized transaction.

Constructors

DecodedBchOutput({required BigInt value, required Uint8List script})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
script Uint8List
final
value BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited