PsbtKeyValue class
One key/value entry of a PSBT map.
Constructors
- PsbtKeyValue({required int keyType, required Uint8List keyData, required Uint8List value})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyData → Uint8List
-
The key bytes after the type byte.
final
- keyType → int
-
The first key byte (the entry type).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Uint8List
-
The entry value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited