Verified class final

Verified cryptographically / byte-for-byte.

Inheritance

Constructors

Verified()
const

Properties

checked bool
Whether anything was actually verified (Verified only).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
ok bool
Whether the reply is acceptable.
no setteroverride
reason String?
Human-readable explanation for a failure or an unverifiable input; null when verified.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited