VerifyBchInput class
One request input, as named to the device.
Constructors
- VerifyBchInput({required String txid, required int index, required Object value, required Object publicKey})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- publicKey → Object
-
The compressed public key the request named as the UTXO owner
(Uint8List or hex String).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- txid → String
-
Display-order txid, 64 hex chars — as sent in the request.
final
- value → Object
-
UTXO value in satoshis (int or BigInt) — as sent in the request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited