VerifyBchOutput class

One request output, as named to the device.

Constructors

VerifyBchOutput({required String address, required Object value})
const

Properties

address String
CashAddr as sent in the request (prefixed or bare).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object
Output value in satoshis (int or BigInt).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited