VerifyBchSignedTxArgs class

Inputs for verifyBchSignedTx.

Constructors

VerifyBchSignedTxArgs({required String rawTx, required List<VerifyBchInput> inputs, required List<VerifyBchOutput> outputs, String? txId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputs List<VerifyBchInput>
final
outputs List<VerifyBchOutput>
final
rawTx String
The reply's rawTx hex.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txId String?
The reply's txId, when you want it checked against the raw bytes too.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited