VerifyBtcMessageHeaderArgs class

Constructors

VerifyBtcMessageHeaderArgs({required String address, required Uint8List signature})
const

Properties

address String
The address the request asked the device to sign with.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
The raw 65-byte BIP-137 signature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited