VerifyCardanoAccount class

The linked account's key material, from accounts.cardano(): the account xpub halves and its path.

Constructors

VerifyCardanoAccount({required Uint8List publicKey, required Uint8List chainCode, required String accountPath})
const

Properties

accountPath String
final
chainCode Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
publicKey Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited