publicKey property
33-byte compressed public key (from the reply, or derived from your linked xpub).
Implementation
final Uint8List publicKey;
33-byte compressed public key (from the reply, or derived from your linked xpub).
final Uint8List publicKey;