VerifyResult class sealed

Outcome of a verification helper. Helpers return, never throw, on mismatches.

A sealed result: Verified, Unverifiable (ok but nothing was checkable client-side) and Failed.

Implementers

Properties

checked bool
Whether anything was actually verified (Verified only).
no setter
hashCode int
The hash code for this object.
no setterinherited
ok bool
Whether the reply is acceptable.
no setter
reason String?
Human-readable explanation for a failure or an unverifiable input; null when verified.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited