reason property
String?
get
reason
Human-readable explanation for a failure or an unverifiable input;
null when verified.
Implementation
String? get reason;
Human-readable explanation for a failure or an unverifiable input;
null when verified.
String? get reason;