VerifyXrpSignatureArgs class
Inputs for verifyXrpSignature.
Constructors
- VerifyXrpSignatureArgs({required Uint8List signedTx, required String expectedSigningPubKey})
-
const
Properties
- expectedSigningPubKey → String
-
The
SigningPubKeyhex your request JSON carried (33-byte compressed secp256k1).final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signedTx → Uint8List
-
The signed binary transaction from the reply.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited