EvmChain class
The EVM chain module: eth-sign-request out, eth-signature back.
Constructors
- EvmChain([EraConnectConfig? config])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateSignRequest(
EvmSignRequestProps props) → SignRequest< EvmSignatureResult> -
Build an
eth-sign-request(401). Reply:eth-signature(402). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseSignature(
Object input, [ExpectedReply? expect]) → EvmSignatureResult -
Parse an
eth-signaturestandalone. Withoutexpect.requestIdthe echo is returned but not validated — preferSignRequest.scanner().parse(). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited