SuiChain class
Sui signing over the ERA UR protocol.
Constructors
- SuiChain([EraConnectConfig? config])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateSignHashRequest(
SuiSignHashRequestProps props) → SignRequest< SuiSignatureResult> -
Build a
sui-sign-hash-request(7103) — signs the given 32-byte digest directly. -
generateSignRequest(
SuiSignRequestProps props) → SignRequest< SuiSignatureResult> -
Build a
sui-sign-request(7101). Reply:sui-signature(7102). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseSignature(
Object input, [ExpectedReply? expect]) → SuiSignatureResult -
Parse a
sui-signaturestandalone. PreferSignRequest.scanner().parse(). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited