TonChain class
TON: ton-sign-request (7201) / ton-signature (7202).
Constructors
- TonChain([EraConnectConfig? config])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateSignRequest(
TonSignRequestProps props) → SignRequest< TonSignatureResult> -
Build a
ton-sign-request(7201). Reply:ton-signature(7202). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseSignature(
Object input, [ExpectedReply? expect]) → TonSignatureResult -
Parse a
ton-signaturestandalone. PreferSignRequest.scanner().parse(). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited