DecodedBchTx class
A decoded legacy-serialized Bitcoin Cash transaction.
Constructors
-
DecodedBchTx({required int version, required List<
DecodedBchInput> inputs, required List<DecodedBchOutput> outputs, required int locktime}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputs
→ List<
DecodedBchInput> -
final
- locktime → int
-
final
-
outputs
→ List<
DecodedBchOutput> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited