ParsedPsbt class
A structurally parsed PSBT v0.
Constructors
-
ParsedPsbt({required Uint8List unsignedTx, required int version, required List<
List< inputs, required List<PsbtKeyValue> >List< outputs})PsbtKeyValue> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputs
→ List<
List< PsbtKeyValue> > -
Per-input key/value maps.
final
-
outputs
→ List<
List< PsbtKeyValue> > -
Per-output key/value maps.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unsignedTx → Uint8List
-
The global UNSIGNED_TX value, verbatim.
final
- version → int
-
Global PSBT_GLOBAL_VERSION (0xFB) if present; v0 files normally omit it.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited