VerifySuiSignatureArgs class
Inputs for verifySuiSignature.
Constructors
Properties
- expectedPublicKey → Uint8List?
-
The linked account's key (
accounts.sui()[i].publicKey) — binds the reply to YOUR wallet.final - hashCode → int
-
The hash code for this object.
no setterinherited
- intentMessage → Uint8List?
-
The intent message the request carried (or pass messageHash for the
hash variant).
final
- messageHash → Uint8List?
-
final
- publicKey → Uint8List
-
The signer key the reply carried.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → Uint8List
-
64-byte Ed25519 signature from the reply.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited