VerifyTonSignatureArgs class
Arguments for verifyTonSignature.
Constructors
- VerifyTonSignatureArgs({required Uint8List signData, required int dataType, required Uint8List signature, required Uint8List publicKey})
-
const
Properties
- dataType → int
-
The request's TonDataType.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicKey → Uint8List
-
The 32-byte signer public key from linking (
accounts.ton()).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → Uint8List
-
64-byte Ed25519 signature from the reply.
final
- signData → Uint8List
-
The exact bytes the request carried in
signData.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited